diff --git a/src/Display/DisplayPluginBase.php b/src/Display/DisplayPluginBase.php
index f9553c4..1d87d96 100644
--- a/src/Display/DisplayPluginBase.php
+++ b/src/Display/DisplayPluginBase.php
@@ -134,22 +134,17 @@ abstract class DisplayPluginBase extends PluginBase implements DisplayInterface
   /**
    * {@inheritdoc}
    */
-  public function getUrl() {
-    $plugin_definition = $this->getPluginDefinition();
-    if (!empty($plugin_definition['path'])) {
-      return Url::fromUserInput($plugin_definition['path']);
-    }
-    return NULL;
+  public function getPath() {
+    return FALSE;
   }
 
   /**
    * {@inheritdoc}
    */
   public function isRenderedInCurrentRequest() {
-    $plugin_definition = $this->getPluginDefinition();
-    if (!empty($plugin_definition['path'])) {
-      $current_path = $this->getCurrentPath()->getPath();
-      return $current_path == $plugin_definition['path'];
+    if ($display_route = $this->getPath()) {
+      $current_route = \Drupal::routeMatch()->getRouteName();
+      return $display_route == $current_route;
     }
     return FALSE;
   }
diff --git a/src/Plugin/search_api/display/ViewsBlock.php b/src/Plugin/search_api/display/ViewsBlock.php
index acfa87b..9b3733e 100644
--- a/src/Plugin/search_api/display/ViewsBlock.php
+++ b/src/Plugin/search_api/display/ViewsBlock.php
@@ -16,7 +16,7 @@ class ViewsBlock extends ViewsDisplayBase {
   /**
    * {@inheritdoc}
    */
-  public function getUrl() {
+  public function getPath() {
     // Blocks don't have a path, so don't return one.
     return NULL;
   }
diff --git a/src/Plugin/search_api/display/ViewsDisplayBase.php b/src/Plugin/search_api/display/ViewsDisplayBase.php
index ce470a9..fbae16f 100644
--- a/src/Plugin/search_api/display/ViewsDisplayBase.php
+++ b/src/Plugin/search_api/display/ViewsDisplayBase.php
@@ -33,4 +33,16 @@ abstract class ViewsDisplayBase extends DisplayPluginBase {
       ->load($plugin_definition['view_id']);
   }
 
+  /**
+   * {@inheritdoc}
+   */
+  public function getPath() {
+    $plugin_definition = $this->getPluginDefinition();
+    // Views without a path set do not have an URI.
+    if (!empty($plugin_definition['path'])) {
+      return 'view.' . $plugin_definition['view_id'] . '.' . $plugin_definition['view_display'];
+    }
+    return FALSE;
+  }
+
 }

diff --git a/src/Display/DisplayInterface.php b/src/Display/DisplayInterface.php
index 2b6d8c5..017b52d 100644
--- a/src/Display/DisplayInterface.php
+++ b/src/Display/DisplayInterface.php
@@ -42,12 +42,12 @@ interface DisplayInterface extends PluginInspectionInterface, DerivativeInspecti
   public function getIndex();
 
   /**
    * Returns the URL of this display.
    *
-   * @return \Drupal\Core\Url|null
-   *   The URL of the display, or NULL if there is no specific URL for it.
+   * @return string|false
+   *   The uri for this display, or FALSE if there is no specific URI.
    */
-  public function getUrl();
+  public function getPath();
 
   /**
    * Returns true if the display is being rendered in the current request.
@@ -42,12 +42,12 @@ interface DisplayInterface extends PluginInspectionInterface, DerivativeInspecti
 
   /**
-   * Returns the URL of this display.
+   * Returns the path of this display.
    *